==> qcad-3.15.5.3.tgz: lib/qcad/scripts/File/AutoSave/ts/AutoSave_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>AutoSave</name>
    <message>
        <location filename="../AutoSave.js" line="+34"/>
        <source>Load/Save</source>
        <translation>Načítať/Uložiť</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Autosave</source>
        <translation>Automatické ukladanie</translation>
    </message>
    <message>
        <location line="+95"/>
        <source>Autosaving to:</source>
        <translation>Automaticky ukladať do:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Autosave failed:</source>
        <translation>Automatické ukladanie zlyhalo:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Autosave complete.</source>
        <translation>Automatické ukladanie dokončené.</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>An &apos;autosave&apos; backup file for an untitled drawing was found.
Do you wish to recover it?</source>
        <translation>Bol nájdený súbor &apos;bez názvu&apos; automatickým uložením.
Prajete si ho obnoviť?</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>%1 &apos;autosave&apos; backup files for untitled drawings were found.
Do you wish to recover them?</source>
        <translation>Boli nájdené %1 súbory(ov) &apos;bez názvu&apos; auto. uložením.Prajete si ich obnoviť?</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Recover Files?</source>
        <translation>Obnoviť súbory?</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Recovered</source>
        <translation>Obnovené</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>Recover File?</source>
        <translation>Obnoviť súbor?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>An &apos;autosave&apos; backup file for &apos;%1&apos; exists.
Do you wish to recover it?</source>
        <translation>Auto. uložením súbor &apos;%1&apos; existuje.
Prajete si ho obnoviť?</translation>
    </message>
    <message>
        <location line="+25"/>
        <location line="+11"/>
        <location line="+5"/>
        <source>Cannot rename file:</source>
        <translation>Nie je možné premenovať súbor:</translation>
    </message>
    <message>
        <location line="-13"/>
        <source>Moved autosave backup file to:</source>
        <translation>Automatickým uložením súbor presunúť do:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Moved original file to:</source>
        <translation>Pôvodný súbor presunúť do:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Cannot remove file:</source>
        <translation>Nie je možné zmazať súbor:</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Enable Autosave</source>
        <translation>Aktivovať automatické ukladanie</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Autosave Interval:</source>
        <translation>Interval ukladania:</translation>
    </message>
    <message>
        <location line="+54"/>
        <source>min</source>
        <translation>min.</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/File/AutoSave/ts/AutoSave_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>AutoSave</name>
    <message>
        <source>Load/Save</source>
        <translation type="vanished">Načítať/Uložiť</translation>
    </message>
    <message>
        <location filename="../AutoSave.js" line="+35"/>
        <source>Autosave</source>
        <translation>Automatické ukladanie</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>File</source>
        <translation>Súbor</translation>
    </message>
    <message>
        <location line="+95"/>
        <source>Autosaving to:</source>
        <translation>Automaticky ukladať do:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Autosave failed:</source>
        <translation>Automatické ukladanie zlyhalo:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Autosave complete.</source>
        <translation>Automatické ukladanie dokončené.</translation>
    </message>
    <message>
        <source>An &apos;autosave&apos; backup file for an untitled drawing was found.
Do you wish to recover it?</source>
        <translation type="vanished">Bol nájdený súbor &apos;bez názvu&apos; automatickým uložením.
Prajete si ho obnoviť?</translation>
    </message>
    <message>
        <source>%1 &apos;autosave&apos; backup files for untitled drawings were found.
Do you wish to recover them?</source>
        <translation type="vanished">Boli nájdené %1 súbory(ov) &apos;bez názvu&apos; auto. uložením.Prajete si ich obnoviť?</translation>
    </message>
    <message numerus="yes">
        <location line="+19"/>
        <source>%n &apos;autosave&apos; backup file(s) for (an) untitled drawing(s) was/were found.
Do you wish to recover it/them?</source>
        <translation>
            <numerusform>%n &apos;autosave&apos; záložný súbor(-y) výkresu(-ov) bez názvu bol/boli nájdené.
Chcete ho/ich obnoviť?</numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Recover Files?</source>
        <translation>Obnoviť súbory?</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Recovered</source>
        <translation>Obnovené</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>Recover File?</source>
        <translation>Obnoviť súbor?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>An &apos;autosave&apos; backup file for &apos;%1&apos; exists.
Do you wish to recover it?</source>
        <translation>Auto. uložením súbor &apos;%1&apos; existuje.
Prajete si ho obnoviť?</translation>
    </message>
    <message>
        <location line="+25"/>
        <location line="+11"/>
        <location line="+5"/>
        <source>Cannot rename file:</source>
        <translation>Nie je možné premenovať súbor:</translation>
    </message>
    <message>
        <location line="-13"/>
        <source>Moved autosave backup file to:</source>
        <translation>Automatickým uložením súbor presunúť do:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Moved original file to:</source>
        <translation>Pôvodný súbor presunúť do:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Cannot remove file:</source>
        <translation>Nie je možné zmazať súbor:</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Enable Autosave</source>
        <translation>Aktivovať automatické ukladanie</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Autosave Interval:</source>
        <translation>Interval ukladania:</translation>
    </message>
    <message>
        <location line="+54"/>
        <source>min</source>
        <translation>min.</translation>
    </message>
</context>
</TS>
